/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.function;

import java.util.List;
import java.util.Set;

import org.tinygroup.function.config.DomainDefines;
import org.tinygroup.function.config.FunctionDefines;

/**
 * 函数管理器
 * 
 * @author luoguo
 * 
 */
public interface FunctionManagerFactory {
	String FUNCTION_MANAGER_FACTORY_BEAN_NAME = "functionManagerFactory";
	String XSTREAM_FUNCTION_PACKAGE_NAME = "function";
	String XSTREAM_DOMAIN_PACKAGE_NAME = "domain";

	/**
	 * 返回某一分类下的函数列表
	 * 
	 * @param group
	 * @return
	 */
	List<Function<?>> getGroupFunctions(String group);

	/**
	 * 返回支持的Domain
	 * 
	 * @return
	 */
	Set<String> getDomains();

	/**
	 * 返回分组列表
	 * 
	 * @return
	 */
	Set<String> getGroups();

	/**
	 * 返回指定领域的管理器，多类模式
	 * 
	 * @param groupName
	 * @return
	 */
	FunctionManager getFunctionManager(String domainName);

	/**
	 * 添加领域定义
	 * 
	 * @param domainDefines
	 */
	void addDomainDefines(DomainDefines domainDefines);

	/**
	 * 添加函数定义
	 * 
	 * @param functionDefines
	 */
	void addFunctionDefines(FunctionDefines functionDefines);
}
